package LATMOS::Accounts::Web::Controller::Remote::Write;
use Moose;
use namespace::autoclean;
use LATMOS::Accounts::Log;

BEGIN { extends 'Catalyst::Controller'; }

=head1 NAME

LATMOS::Accounts::Web::Controller::Remote::Write - Catalyst Controller

=head1 DESCRIPTION

Catalyst Controller.

=head1 METHODS

=cut


=head2 index

=cut

sub index :Path :Args(0) {
    my ( $self, $c ) = @_;

}

sub create :Local :Args(0) {
    my ( $self, $c ) = @_;

    my $name  = $c->req->param('name');
    my $otype = $c->req->param('otype');

    my %info = ();

    foreach my $attr (keys %{ $c->req->params }) {
        $attr =~ /^(name|otype)$/ and next;
        $info{$attr} = $c->req->params->{$attr};
    }

    my $res = $c->model('Accounts')->db->create_c_object($otype, $name, %info);
    if (!$res) {
        $c->stash->{data}{error} = LATMOS::Accounts::Log::lastmessage(LA_ERR);
    }

    $c->stash->{data}{result} = $res ? 1 : 0;
}

sub modify :Local :Args(0) {
    my ( $self, $c ) = @_;

    my $name  = $c->req->param('name');
    my $otype = $c->req->param('otype');

    my %info = ();

    foreach my $attr (keys %{ $c->req->params }) {
        $attr =~ /^(name|otype)$/ and next;
        $info{$attr} = $c->req->params->{$attr};
    }

    if (my $obj = $c->model('Accounts')->db->get_object($otype, $name)) {
        $c->stash->{data}{result} = $obj->set_c_fields(%info) || 0;
        if (! $c->stash->{data}{result}) {
            $c->stash->{data}{error} = LATMOS::Accounts::Log::lastmessage(LA_ERR);
        }
    } else {
        $c->stash->{data}{result} = 0;
        $c->stash->{data}{error} = 'No such object';
    }
}

sub delete :Local :Args(0) {
    my ( $self, $c ) = @_;

    my $name  = $c->req->param('name');
    my $otype = $c->req->param('otype');
    if (!$c->model('Accounts')->db->get_object($otype, $name)) {
        $c->stash->{data}{result} = 0;
        $c->stash->{data}{error} = 'No such object';
        return;
    }

    my $res = $c->model('Accounts')->db->delete_object($otype, $name); 
    $c->stash->{data}{result} = $res ? 1 : 0;
    if (! $c->stash->{data}{result}) {
        $c->stash->{data}{error} = LATMOS::Accounts::Log::lastmessage(LA_ERR);
    }
}


=encoding utf8

=head1 AUTHOR

Olivier Thauvin,Guyancourt - B1428,+33 1 80285052,

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

__PACKAGE__->meta->make_immutable;

1;
